@@ -137,7 +137,7 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 	// Python lacks a FromSpecWithMeta so we are going to have to fake it here.
 	PyTypeObject* type = (PyTypeObject*) PyJPClass_Type->tp_alloc(PyJPClass_Type, 0);
 	PyHeapTypeObject* heap = (PyHeapTypeObject*) type;
-	type->tp_flags = spec->flags | Py_TPFLAGS_HEAPTYPE | Py_TPFLAGS_HAVE_GC;
+	type->tp_flags = spec->flags | Py_TPFLAGS_HEAPTYPE;
 	type->tp_name = spec->name;
 	const char *s = strrchr(spec->name, '.');
 	if (s == NULL)
@@ -283,6 +283,17 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 				// GCOVR_EXCL_STOP
 		}
 	}
+
+	// GC objects are required to implement clear and traverse, this is a
+	// safety check to make sure we implemented all properly.   This error should
+	// never happen in production code.
+	if (PyType_IS_GC(type) && (
+			type->tp_traverse==NULL ||
+			type->tp_clear==NULL))
+	{
+		PyErr_Format(PyExc_TypeError, "GC requirements failed for %s", spec->name);
+		JP_RAISE_PYTHON();
+	}
 	PyType_Ready(type);
 	PyDict_SetItemString(type->tp_dict, "__module__", PyUnicode_FromString("_jpype"));
 	return (PyObject*) type;
@@ -712,10 +723,9 @@ static PyObject *PyJPClass_array(PyJPClass *self, PyObject *item)
 	if (PyIndex_Check(item))
 	{
 		long sz = PyLong_AsLong(item);
-		JPClass *cls = self->m_Class->newArrayType(frame, 1);
-		jvalue v;
-		v.l = (jobject) cls->newArrayOf(frame, sz);
-		return cls->convertToPythonObject(frame, v, true).keep();
+		JPArrayClass *cls = (JPArrayClass*) self->m_Class->newArrayType(frame, 1);
+		JPValue v = cls->newArray(frame, sz);
+		return cls->convertToPythonObject(frame, v.getValue(), true).keep();
 	}
 
 	if (PySlice_Check(item))
@@ -989,7 +999,7 @@ static PyType_Spec classSpec = {
 	"_jpype._JClass",
 	sizeof (PyJPClass),
 	0,
-	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,
+	Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC,
 	classSlots
 };
 
