@@ -55,8 +55,10 @@ static void PyJPMethod_dealloc(PyJPMethod *self)
 {
 	JP_PY_TRY("PyJPMethod_dealloc");
 	PyObject_GC_UnTrack(self);
+	Py_TRASHCAN_BEGIN(self, PyJPMethod_dealloc)
 	PyJPMethod_clear(self);
 	Py_TYPE(self)->tp_free(self);
+	Py_TRASHCAN_END
 	JP_PY_CATCH_NONE(); // GCOVR_EXCL_LINE
 }
 
@@ -398,8 +400,7 @@ void PyJPMethod_initType(PyObject* module)
 	unsigned long flags = PyFunction_Type.tp_flags;
 	PyFunction_Type.tp_flags |= Py_TPFLAGS_BASETYPE;
 	PyJPMethod_Type = (PyTypeObject*) PyType_FromSpecWithBases(&methodSpec, tuple.get());
-	PyFunction_Type.tp_flags = flags;
-	JP_PY_CHECK();
+	PyFunction_Type.tp_flags = flags;	JP_PY_CHECK();
 
 	PyModule_AddObject(module, "_JMethod", (PyObject*) PyJPMethod_Type);
 	JP_PY_CHECK();
